package com.ztmap.project.zhny.energystorageoverview.service;

import java.util.List;
import com.ztmap.project.zhny.energystorageoverview.domain.TEnergyStorageOverview;

/**
 * 储能总览Service接口
 * 
 * @author ztmap
 * @date 2023-10-09
 */
public interface ITEnergyStorageOverviewService 
{
    /**
     * 查询储能总览
     * 
     * @param id 储能总览ID
     * @return 储能总览
     */
    public TEnergyStorageOverview selectTEnergyStorageOverviewById(Long id);

    /**
     * 查询储能总览列表
     * 
     * @param tEnergyStorageOverview 储能总览
     * @return 储能总览集合
     */
    public List<TEnergyStorageOverview> selectTEnergyStorageOverviewList(TEnergyStorageOverview tEnergyStorageOverview);

    /**
     * 新增储能总览
     * 
     * @param tEnergyStorageOverview 储能总览
     * @return 结果
     */
    public int insertTEnergyStorageOverview(TEnergyStorageOverview tEnergyStorageOverview);

    /**
     * 修改储能总览
     * 
     * @param tEnergyStorageOverview 储能总览
     * @return 结果
     */
    public int updateTEnergyStorageOverview(TEnergyStorageOverview tEnergyStorageOverview);

    /**
     * 批量删除储能总览
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteTEnergyStorageOverviewByIds(String ids);

    /**
     * 删除储能总览信息
     * 
     * @param id 储能总览ID
     * @return 结果
     */
    public int deleteTEnergyStorageOverviewById(Long id);
}
